Topos
=====

.. image:: https://travis-ci.org/alcarney/topos.svg?branch=master
    :target: https://travis-ci.org/alcarney/topos

.. image:: https://coveralls.io/repos/github/alcarney/topos/badge.svg?branch=master
    :target: https://coveralls.io/github/alcarney/topos?branch=master

.. image:: https://readthedocs.org/projects/topos/badge/?version=latest
    :target: http://topos.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

Creating 3D meshes with a blend of python and maths

README under construction...
